@@ -27,6 +27,9 @@ except ImportError:
     pass  # Not needed for execution
 from . import ProgressBarBase
 
+__version__ = "0.0.0-auto.0"
+__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_ProgressBar.git"
+
 
 # pylint: disable=too-few-public-methods
 class HorizontalFillDirection:
